pub enum ChildKillMode {
SIGTERM,
SIGKILL,
}Variants
SIGTERM
Sends the SIGTERM signal, and then waits for the process to terminate. Note that this may block indefinitely if the process does not respect SIGTERM.
SIGKILL
Sends the SIGKILL signal, which forcefully kills the process. This is the default mode.